@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,7 @@
 
 #include "configurewidget.h"
 
-#include <Akonadi/Contact/ContactEditor>
+#include <Akonadi/ContactEditor>
 
 #include <KContacts/VCardConverter>
 
@@ -31,16 +31,16 @@ ContactPrintThemeConfigureDialog::ContactPrintThemeConfigureDialog(QWidget *pare
 {
     setWindowTitle(i18nc("@title:window", "Configure"));
 
-    QTabWidget *tab = new QTabWidget;
+    auto tab = new QTabWidget;
 
-    QWidget *w = new QWidget;
-    QVBoxLayout *lay = new QVBoxLayout();
+    auto w = new QWidget;
+    auto lay = new QVBoxLayout();
     w->setLayout(lay);
 
     mConfigureWidget = new GrantleeThemeEditor::ConfigureWidget;
     lay->addWidget(mConfigureWidget);
 
-    QLabel *lab = new QLabel(i18n("Default contact:"));
+    auto lab = new QLabel(i18n("Default contact:"));
     lay->addWidget(lab);
 
     mDefaultContact = new Akonadi::AkonadiContactEditor(Akonadi::AkonadiContactEditor::CreateMode, Akonadi::AkonadiContactEditor::VCardMode);
@@ -51,9 +51,9 @@ ContactPrintThemeConfigureDialog::ContactPrintThemeConfigureDialog(QWidget *pare
     mDefaultTemplate = new KPIMTextEdit::PlainTextEditorWidget;
     tab->addTab(mDefaultTemplate, i18n("Default Template"));
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(tab);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
